(***********************************************************************)
(*                                                                     *)
(*                             Pio (OCaml)                             *)
(*                                                                     *)
(*                    Polyglot Input/Output Library                    *)
(*                                                                     *)
(*                  projet Estime, INRIA-Rocquencourt                  *)
(*                                                                     *)
(*  Copyright 2004-2011 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: my_command_option.mli,v 1.2 2011-02-23 17:43:29 fclement Exp $ *)

val make_antonymic_flags :
    bool -> (unit -> bool) * (unit -> unit) * (unit -> bool) * (unit -> unit);;
(** [make_antonymic_flags b] returns four functions [get, set, get_antonymic,
    set_antonymic] such that [get] and [set] correspond to a flag with default
    value [b], and [get_antonymic] and [set_antonymic] correspond to the
    antonymic flag. *)

val doc_with_valid_list : string -> string -> string;;

val doc_with_default : string -> string -> string;;

val doc_with_valid_list_and_default : string -> string -> string -> string;;

val add_debug_flag :
    string -> string -> ((unit -> bool) * (string -> 'a));;
(** [add_debug_flag long short] adds debug command option with long key
   ["--debug_" ^ long], and short key ["-d" ^ short].
   It returns the couple of functions [get_debug, fatal_error] to ask for the
    value of the flag, and to print a fatal error message and exit. *)

val add_user_debug_flag :
    string -> string -> ((unit -> bool) * (string -> 'a));;
(** [add_user_debug_flag long short] adds user's debug command option with long
   key ["--debug_" ^ long], and short key ["-d" ^ short].
   It returns the couple of functions [get_debug, fatal_error] to ask for the
    value of the flag, and to print a fatal error message and exit. *)

val add_report_and_debug_flags :
    string -> string -> ((unit -> bool) * (unit -> bool) * (string -> 'a));;
(** [add_report_and_debug_flags long short] adds report and debug command
   options with respective long keys ["--report_" ^ long] and
   ["--debug_" ^ long], and respective short keys ["-r" ^ short] and
   ["-d" ^ short].
   It returns the triple of functions [get_report, get_debug, fatal_error] to
   ask for the value of the corresponding flag, and to print a fatal error
   message and exit. *)

val add_user_report_and_debug_flags :
    string -> string -> ((unit -> bool) * (unit -> bool) * (string -> 'a));;
(** [add_user_report_and_debug_flags long short] adds user's report and debug
   command options with respective long keys ["--report_" ^ long] and
   ["--debug_" ^ long], and respective short keys ["-r" ^ short] and
   ["-d" ^ short].
   It returns the triple of functions [get_report, get_debug, fatal_error] to
   ask for the value of the corresponding flag, and to print a fatal error
   message and exit. *)
